#!/usr/bin/env python

from __future__ import print_function, unicode_literals

import argparse
import os

from sqlalchemy import create_engine


parser = argparse.ArgumentParser(
    description="Create/Update the Pagure database"
)
parser.add_argument(
    "--config",
    "-c",
    dest="config",
    help="Configuration file to use for pagure.",
)

args = parser.parse_args()

if args.config:
    config = args.config
    if not config.startswith("/"):
        here = os.path.join(os.path.dirname(os.path.abspath(__file__)))
        config = os.path.join(here, config)
    print(config)
    os.environ["PAGURE_CONFIG"] = config

import pagure.config
from pagure_distgit.model import (
    BASE,
    PagureAnitya,
    PagureBZOverride,
    PagureOrphanReason,
)

db_url = pagure.config.config.get("DB_URL")
if db_url.startswith("postgres"):
    engine = create_engine(db_url, echo=True, client_encoding="utf8")
else:
    engine = create_engine(db_url, echo=True)

BASE.metadata.create_all(
    engine,
    tables=[
        PagureAnitya.__table__,
        PagureBZOverride.__table__,
        PagureOrphanReason.__table__,
    ],
)
